Index: mojo/tools/run_mojo_python_tests.py |
diff --git a/mojo/tools/run_mojo_python_tests.py b/mojo/tools/run_mojo_python_tests.py |
index d18baf4f6efa4ff9af10908eac357444f704f50b..f4da223ab9b3043bf3ef0546a84220be5680ed69 100755 |
--- a/mojo/tools/run_mojo_python_tests.py |
+++ b/mojo/tools/run_mojo_python_tests.py |
@@ -15,8 +15,10 @@ def main(): |
os.path.join('mojo', 'public', 'tools', 'bindings', 'pylib'), |
# Tests of "mopy" python tools code. |
os.path.join('mojo', 'tools', 'mopy'), |
- # Tests of python code in devtools. |
- os.path.join('mojo', 'devtools', 'common', 'devtoolslib') |
+ # Tests of python code in devtools library. |
+ os.path.join('mojo', 'devtools', 'common', 'devtoolslib'), |
+ # Tests of the android stack parser (in devtools). |
ppi
2015/08/21 14:53:07
nit: no need to state the obvious, I'd drop this c
etiennej
2015/08/21 15:07:18
Done.
|
+ os.path.join('mojo', 'devtools', 'common', 'android_stack_parser') |
] |
for test_dir in test_dir_list: |